#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
/************************************************************/
void createTitleResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin Title\n");
	fprintf(fout,"	Residue        : PDB type atom  Amber type atom  charge of atom\n");
	fprintf(fout,"End\n");
}
/************************************************************/
void createListResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin Residue List\n");
	fprintf(fout,"HOH\n");
	fprintf(fout,"T3P\n");
	fprintf(fout,"T3H\n");
	fprintf(fout,"T4P\n");
	fprintf(fout,"T4E\n");
	fprintf(fout,"T5P\n");
	fprintf(fout,"IB+\n");
	fprintf(fout,"Ca+\n");
	fprintf(fout,"Cl-\n");
	fprintf(fout,"Na+\n");
	fprintf(fout,"Mg+\n");
	fprintf(fout,"K+\n");
	fprintf(fout,"Rb+\n");
	fprintf(fout,"Cs+\n");
	fprintf(fout,"Li+\n");
	fprintf(fout,"Zn+\n");
	fprintf(fout,"Sr+\n");
	fprintf(fout,"Ba+\n");
	fprintf(fout,"URE\n");
	fprintf(fout,"ACE\n");
	fprintf(fout,"NME\n");
	fprintf(fout,"NHE\n");
	fprintf(fout,"NH2\n");
	fprintf(fout,"ALA\n");
	fprintf(fout,"GLY\n");
	fprintf(fout,"SER\n");
	fprintf(fout,"THR\n");
	fprintf(fout,"LEU\n");
	fprintf(fout,"ILE\n");
	fprintf(fout,"VAL\n");
	fprintf(fout,"ASN\n");
	fprintf(fout,"GLN\n");
	fprintf(fout,"ARG\n");
	fprintf(fout,"HID\n");
	fprintf(fout,"HIE\n");
	fprintf(fout,"HIP\n");
	fprintf(fout,"TRP\n");
	fprintf(fout,"PHE\n");
	fprintf(fout,"TYR\n");
	fprintf(fout,"GLU\n");
	fprintf(fout,"ASP\n");
	fprintf(fout,"LYP\n");
	fprintf(fout,"ORN\n");
	fprintf(fout,"DAB\n");
	fprintf(fout,"LYN\n");
	fprintf(fout,"PRO\n");
	fprintf(fout,"HYP\n");
	fprintf(fout,"CYN\n");
	fprintf(fout,"CYM\n");
	fprintf(fout,"CYX\n");
	fprintf(fout,"CYS2\n");
	fprintf(fout,"MET\n");
	fprintf(fout,"ASH\n");
	fprintf(fout,"GLH\n");
	fprintf(fout,"CALA\n");
	fprintf(fout,"CGLY\n");
	fprintf(fout,"CSER\n");
	fprintf(fout,"CTHR\n");
	fprintf(fout,"CLEU\n");
	fprintf(fout,"CILE\n");
	fprintf(fout,"CVAL\n");
	fprintf(fout,"CASN\n");
	fprintf(fout,"CGLN\n");
	fprintf(fout,"CARG\n");
	fprintf(fout,"CHID\n");
	fprintf(fout,"CHIE\n");
	fprintf(fout,"CHIP\n");
	fprintf(fout,"CTRP\n");
	fprintf(fout,"CPHE\n");
	fprintf(fout,"CTYR\n");
	fprintf(fout,"CGLU\n");
	fprintf(fout,"CASP\n");
	fprintf(fout,"CLYP\n");
	fprintf(fout,"CPRO\n");
	fprintf(fout,"CCYN\n");
	fprintf(fout,"CCYX\n");
	fprintf(fout,"CMET\n");
	fprintf(fout,"NALA\n");
	fprintf(fout,"NGLY\n");
	fprintf(fout,"NSER\n");
	fprintf(fout,"NTHR\n");
	fprintf(fout,"NLEU\n");
	fprintf(fout,"NILE\n");
	fprintf(fout,"NVAL\n");
	fprintf(fout,"NASN\n");
	fprintf(fout,"NGLN\n");
	fprintf(fout,"NARG\n");
	fprintf(fout,"NHID\n");
	fprintf(fout,"NHIE\n");
	fprintf(fout,"NHIP\n");
	fprintf(fout,"NTRP\n");
	fprintf(fout,"NPHE\n");
	fprintf(fout,"NTYR\n");
	fprintf(fout,"NGLU\n");
	fprintf(fout,"NASP\n");
	fprintf(fout,"NLYP\n");
	fprintf(fout,"NPRO\n");
	fprintf(fout,"NCYN\n");
	fprintf(fout,"NCYX\n");
	fprintf(fout,"NMET\n");
	fprintf(fout,"DA5\n");
	fprintf(fout,"DA\n");
	fprintf(fout,"DA3\n");
	fprintf(fout,"DAN\n");
	fprintf(fout,"RA5\n");
	fprintf(fout,"RA\n");
	fprintf(fout,"RA3\n");
	fprintf(fout,"RAN\n");
	fprintf(fout,"DT5\n");
	fprintf(fout,"DT\n");
	fprintf(fout,"DT3\n");
	fprintf(fout,"DTN\n");
	fprintf(fout,"RU5\n");
	fprintf(fout,"RU\n");
	fprintf(fout,"RU3\n");
	fprintf(fout,"RUN\n");
	fprintf(fout,"DG5\n");
	fprintf(fout,"DG\n");
	fprintf(fout,"DG3\n");
	fprintf(fout,"DGN\n");
	fprintf(fout,"RG5\n");
	fprintf(fout,"RG\n");
	fprintf(fout,"RG3\n");
	fprintf(fout,"RGN\n");
	fprintf(fout,"DC5\n");
	fprintf(fout,"DC\n");
	fprintf(fout,"DC3\n");
	fprintf(fout,"DCN\n");
	fprintf(fout,"RC5\n");
	fprintf(fout,"RC\n");
	fprintf(fout,"RC3\n");
	fprintf(fout,"RCN\n");
	fprintf(fout,"End\n");
}
/************************************************************/
void createResidueTpl(FILE* fout)
{

	fprintf(fout,"Begin HOH Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T3P Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T3H Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T4P Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW2    HW     0.520 \n");
	fprintf(fout,"HW3    HW     0.520 \n");
	fprintf(fout,"MW4    MW     -1.040\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T4E Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW1    HW     0.52422\n");
	fprintf(fout,"HW2    HW     0.52422\n");
	fprintf(fout,"MW     MW     -1.04844\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T5P Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW1    HW     0.241 \n");
	fprintf(fout,"HW2    HW     0.241 \n");
	fprintf(fout,"LP1    MW     -0.241\n");
	fprintf(fout,"LP2    MW     -0.241\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin IB+ Residue\n");
	fprintf(fout,"IB     IB     1.00000\n");
	fprintf(fout,"IB     IB     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Ca+ Residue\n");
	fprintf(fout,"Ca     Ca     2.00000\n");
	fprintf(fout,"Ca     Ca     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Cl- Residue\n");
	fprintf(fout,"Cl     Cl     -1.00000\n");
	fprintf(fout,"Cl     Cl     -1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Na+ Residue\n");
	fprintf(fout,"Na     Na     1.00000\n");
	fprintf(fout,"Na     Na     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Mg+ Residue\n");
	fprintf(fout,"Mg     Mg     2.00000\n");
	fprintf(fout,"Mg     Mg     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin K+ Residue\n");
	fprintf(fout,"K      K      1.00000\n");
	fprintf(fout,"K      K      1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Rb+ Residue\n");
	fprintf(fout,"Rb     Rb     1.00000\n");
	fprintf(fout,"Rb     Rb     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Cs+ Residue\n");
	fprintf(fout,"CS     Cs     1.00000\n");
	fprintf(fout,"CS     Cs     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Li+ Residue\n");
	fprintf(fout,"Li     Li     1.00000\n");
	fprintf(fout,"Li     Li     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Zn+ Residue\n");
	fprintf(fout,"Zn     Zn     2.00000\n");
	fprintf(fout,"Zn     Zn     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Sr+ Residue\n");
	fprintf(fout,"Sr     Sr     2.00000\n");
	fprintf(fout,"Sr     Sr     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Ba+ Residue\n");
	fprintf(fout,"Ba     Ba     2.00000\n");
	fprintf(fout,"Ba     Ba     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin URE Residue\n");
	fprintf(fout,"C      C      0.880229\n");
	fprintf(fout,"O      O      -0.613359\n");
	fprintf(fout,"N1     N      -0.923545\n");
	fprintf(fout,"H11    H      0.395055\n");
	fprintf(fout,"H12    H      0.395055\n");
	fprintf(fout,"N2     N      -0.923545\n");
	fprintf(fout,"H21    H      0.395055\n");
	fprintf(fout,"H22    H      0.395055\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ACE Residue\n");
	fprintf(fout,"HH31   HC     0.11230\n");
	fprintf(fout,"CH3    CT     -0.36620\n");
	fprintf(fout,"HH32   HC     0.11230\n");
	fprintf(fout,"HH33   HC     0.11230\n");
	fprintf(fout,"C      C      0.59720\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NME Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CH3    CT     -0.14900\n");
	fprintf(fout,"HH31   H1     0.09760\n");
	fprintf(fout,"HH32   H1     0.09760\n");
	fprintf(fout,"HH33   H1     0.09760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHE Residue\n");
	fprintf(fout,"N      N      -0.46300\n");
	fprintf(fout,"H1     H      0.23150\n");
	fprintf(fout,"H2     H      0.23150\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NH2 Residue\n");
	fprintf(fout,"N      N      -0.46300\n");
	fprintf(fout,"H1     H      0.23150\n");
	fprintf(fout,"H2     H      0.23150\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ALA Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.03370\n");
	fprintf(fout,"HA     H1     0.08230\n");
	fprintf(fout,"CB     CT     -0.18250\n");
	fprintf(fout,"HB1    HC     0.06030\n");
	fprintf(fout,"HB2    HC     0.06030\n");
	fprintf(fout,"HB3    HC     0.06030\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLY Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02520\n");
	fprintf(fout,"HA1    H1     0.06980\n");
	fprintf(fout,"HA2    H1     0.06980\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin SER Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02490\n");
	fprintf(fout,"HA     H1     0.08430\n");
	fprintf(fout,"CB     CT     0.21170\n");
	fprintf(fout,"HB1    H1     0.03520\n");
	fprintf(fout,"HB2    H1     0.03520\n");
	fprintf(fout,"OG     OH     -0.65460\n");
	fprintf(fout,"HG     HO     0.42750\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin THR Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.03890\n");
	fprintf(fout,"HA     H1     0.10070\n");
	fprintf(fout,"CB     CT     0.36540\n");
	fprintf(fout,"HB     H1     0.00430\n");
	fprintf(fout,"CG2    CT     -0.24380\n");
	fprintf(fout,"HG21   HC     0.06420\n");
	fprintf(fout,"HG22   HC     0.06420\n");
	fprintf(fout,"HG23   HC     0.06420\n");
	fprintf(fout,"OG1    OH     -0.67610\n");
	fprintf(fout,"HG1    HO     0.41020\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LEU Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05180\n");
	fprintf(fout,"HA     H1     0.09220\n");
	fprintf(fout,"CB     CT     -0.11020\n");
	fprintf(fout,"HB1    HC     0.04570\n");
	fprintf(fout,"HB2    HC     0.04570\n");
	fprintf(fout,"CG     CT     0.35310\n");
	fprintf(fout,"HG     HC     -0.03610\n");
	fprintf(fout,"CD1    CT     -0.41210\n");
	fprintf(fout,"HD11   HC     0.10000\n");
	fprintf(fout,"HD12   HC     0.10000\n");
	fprintf(fout,"HD13   HC     0.10000\n");
	fprintf(fout,"CD2    CT     -0.41210\n");
	fprintf(fout,"HD21   HC     0.10000\n");
	fprintf(fout,"HD22   HC     0.10000\n");
	fprintf(fout,"HD23   HC     0.10000\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ILE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05970\n");
	fprintf(fout,"HA     H1     0.08690\n");
	fprintf(fout,"CB     CT     0.13030\n");
	fprintf(fout,"HB     HC     0.01870\n");
	fprintf(fout,"CG2    CT     -0.32040\n");
	fprintf(fout,"HG21   HC     0.08820\n");
	fprintf(fout,"HG22   HC     0.08820\n");
	fprintf(fout,"HG23   HC     0.08820\n");
	fprintf(fout,"CG1    CT     -0.04300\n");
	fprintf(fout,"HG11   HC     0.02360\n");
	fprintf(fout,"HG12   HC     0.02360\n");
	fprintf(fout,"CD     CT     -0.06600\n");
	fprintf(fout,"HD1    HC     0.01860\n");
	fprintf(fout,"HD2    HC     0.01860\n");
	fprintf(fout,"HD3    HC     0.01860\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin VAL Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.08750\n");
	fprintf(fout,"HA     H1     0.09690\n");
	fprintf(fout,"CB     CT     0.29850\n");
	fprintf(fout,"HB     HC     -0.02970\n");
	fprintf(fout,"CG1    CT     -0.31920\n");
	fprintf(fout,"HG11   HC     0.07910\n");
	fprintf(fout,"HG12   HC     0.07910\n");
	fprintf(fout,"HG13   HC     0.07910\n");
	fprintf(fout,"CG2    CT     -0.31920\n");
	fprintf(fout,"HG21   HC     0.07910\n");
	fprintf(fout,"HG22   HC     0.07910\n");
	fprintf(fout,"HG23   HC     0.07910\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01430\n");
	fprintf(fout,"HA     H1     0.10480\n");
	fprintf(fout,"CB     CT     -0.20410\n");
	fprintf(fout,"HB1    HC     0.07970\n");
	fprintf(fout,"HB2    HC     0.07970\n");
	fprintf(fout,"CG     C      0.71300\n");
	fprintf(fout,"OD1    O      -0.59310\n");
	fprintf(fout,"ND2    N      -0.91910\n");
	fprintf(fout,"HD21   H      0.41960\n");
	fprintf(fout,"HD22   H      0.41960\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00310\n");
	fprintf(fout,"HA     H1     0.08500\n");
	fprintf(fout,"CB     CT     -0.00360\n");
	fprintf(fout,"HB1    HC     0.01710\n");
	fprintf(fout,"HB2    HC     0.01710\n");
	fprintf(fout,"CG     CT     -0.06450\n");
	fprintf(fout,"HG1    HC     0.03520\n");
	fprintf(fout,"HG2    HC     0.03520\n");
	fprintf(fout,"CD     C      0.69510\n");
	fprintf(fout,"OE1    O      -0.60860\n");
	fprintf(fout,"NE2    N      -0.94070\n");
	fprintf(fout,"HE21   H      0.42510\n");
	fprintf(fout,"HE22   H      0.42510\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ARG Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.26370\n");
	fprintf(fout,"HA     H1     0.15600\n");
	fprintf(fout,"CB     CT     -0.00070\n");
	fprintf(fout,"HB1    HC     0.03270\n");
	fprintf(fout,"HB2    HC     0.03270\n");
	fprintf(fout,"CG     CT     0.03900\n");
	fprintf(fout,"HG1    HC     0.02850\n");
	fprintf(fout,"HG2    HC     0.02850\n");
	fprintf(fout,"CD     CT     0.04860\n");
	fprintf(fout,"HD1    H1     0.06870\n");
	fprintf(fout,"HD2    H1     0.06870\n");
	fprintf(fout,"NE     N2     -0.52950\n");
	fprintf(fout,"HE     H      0.34560\n");
	fprintf(fout,"CZ     CA     0.80760\n");
	fprintf(fout,"NH1    N2     -0.86270\n");
	fprintf(fout,"HH11   H      0.44780\n");
	fprintf(fout,"HH12   H      0.44780\n");
	fprintf(fout,"NH2    N2     -0.86270\n");
	fprintf(fout,"HH21   H      0.44780\n");
	fprintf(fout,"HH22   H      0.44780\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HID Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01880\n");
	fprintf(fout,"HA     H1     0.08810\n");
	fprintf(fout,"CB     CT     -0.04620\n");
	fprintf(fout,"HB1    HC     0.04020\n");
	fprintf(fout,"HB2    HC     0.04020\n");
	fprintf(fout,"CG     CC     -0.02660\n");
	fprintf(fout,"ND1    NA     -0.38110\n");
	fprintf(fout,"HD1    H      0.36490\n");
	fprintf(fout,"CE1    CR     0.20570\n");
	fprintf(fout,"HE1    H5     0.13920\n");
	fprintf(fout,"NE2    NB     -0.57270\n");
	fprintf(fout,"CD2    CV     0.12920\n");
	fprintf(fout,"HD2    H4     0.11470\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HIE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05810\n");
	fprintf(fout,"HA     H1     0.13600\n");
	fprintf(fout,"CB     CT     -0.00740\n");
	fprintf(fout,"HB1    HC     0.03670\n");
	fprintf(fout,"HB2    HC     0.03670\n");
	fprintf(fout,"CG     CC     0.18680\n");
	fprintf(fout,"ND1    NB     -0.54320\n");
	fprintf(fout,"CE1    CR     0.16350\n");
	fprintf(fout,"HE1    H5     0.14350\n");
	fprintf(fout,"NE2    NA     -0.27950\n");
	fprintf(fout,"HE2    H      0.33390\n");
	fprintf(fout,"CD2    CW     -0.22070\n");
	fprintf(fout,"HD2    H4     0.18620\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HIP Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.13540\n");
	fprintf(fout,"HA     H1     0.12120\n");
	fprintf(fout,"CB     CT     -0.04140\n");
	fprintf(fout,"HB1    HC     0.08100\n");
	fprintf(fout,"HB2    HC     0.08100\n");
	fprintf(fout,"CG     CC     -0.00120\n");
	fprintf(fout,"ND1    NA     -0.15130\n");
	fprintf(fout,"HD1    H      0.38660\n");
	fprintf(fout,"CE1    CR     -0.01700\n");
	fprintf(fout,"HE1    H5     0.26810\n");
	fprintf(fout,"NE2    NA     -0.17180\n");
	fprintf(fout,"HE2    H      0.39110\n");
	fprintf(fout,"CD2    CW     -0.11410\n");
	fprintf(fout,"HD2    H4     0.23170\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin TRP Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02750\n");
	fprintf(fout,"HA     H1     0.11230\n");
	fprintf(fout,"CB     CT     -0.00500\n");
	fprintf(fout,"HB1    HC     0.03390\n");
	fprintf(fout,"HB2    HC     0.03390\n");
	fprintf(fout,"CG     C*     -0.14150\n");
	fprintf(fout,"CD1    CW     -0.16380\n");
	fprintf(fout,"HD1    H4     0.20620\n");
	fprintf(fout,"NE1    NA     -0.34180\n");
	fprintf(fout,"HE1    H      0.34120\n");
	fprintf(fout,"CE2    CN     0.13800\n");
	fprintf(fout,"CZ2    CA     -0.26010\n");
	fprintf(fout,"HZ2    HA     0.15720\n");
	fprintf(fout,"CH2    CA     -0.11340\n");
	fprintf(fout,"HH2    HA     0.14170\n");
	fprintf(fout,"CZ3    CA     -0.19720\n");
	fprintf(fout,"HZ3    HA     0.14470\n");
	fprintf(fout,"CE3    CA     -0.23870\n");
	fprintf(fout,"HE3    HA     0.17000\n");
	fprintf(fout,"CD2    CB     0.12430\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin PHE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00240\n");
	fprintf(fout,"HA     H1     0.09780\n");
	fprintf(fout,"CB     CT     -0.03430\n");
	fprintf(fout,"HB1    HC     0.02950\n");
	fprintf(fout,"HB2    HC     0.02950\n");
	fprintf(fout,"CG     CA     0.01180\n");
	fprintf(fout,"CD1    CA     -0.12560\n");
	fprintf(fout,"HD1    HA     0.13300\n");
	fprintf(fout,"CE1    CA     -0.17040\n");
	fprintf(fout,"HE1    HA     0.14300\n");
	fprintf(fout,"CZ     CA     -0.10720\n");
	fprintf(fout,"HZ     HA     0.12970\n");
	fprintf(fout,"CE2    CA     -0.17040\n");
	fprintf(fout,"HE2    HA     0.14300\n");
	fprintf(fout,"CD2    CA     -0.12560\n");
	fprintf(fout,"HD2    HA     0.13300\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin TYR Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00140\n");
	fprintf(fout,"HA     H1     0.08760\n");
	fprintf(fout,"CB     CT     -0.01520\n");
	fprintf(fout,"HB1    HC     0.02950\n");
	fprintf(fout,"HB2    HC     0.02950\n");
	fprintf(fout,"CG     CA     -0.00110\n");
	fprintf(fout,"CD1    CA     -0.19060\n");
	fprintf(fout,"HD1    HA     0.16990\n");
	fprintf(fout,"CE1    CA     -0.23410\n");
	fprintf(fout,"HE1    HA     0.16560\n");
	fprintf(fout,"CZ     C      0.32260\n");
	fprintf(fout,"OH     OH     -0.55790\n");
	fprintf(fout,"HH     HO     0.39920\n");
	fprintf(fout,"CE2    CA     -0.23410\n");
	fprintf(fout,"HE2    HA     0.16560\n");
	fprintf(fout,"CD2    CA     -0.19060\n");
	fprintf(fout,"HD2    HA     0.16990\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLU Residue\n");
	fprintf(fout,"N      N      -0.51630\n");
	fprintf(fout,"H      H      0.29360\n");
	fprintf(fout,"CA     CT     0.03970\n");
	fprintf(fout,"HA     H1     0.11050\n");
	fprintf(fout,"CB     CT     0.05600\n");
	fprintf(fout,"HB1    HC     -0.01730\n");
	fprintf(fout,"HB2    HC     -0.01730\n");
	fprintf(fout,"CG     CT     0.01360\n");
	fprintf(fout,"HG1    HC     -0.04250\n");
	fprintf(fout,"HG2    HC     -0.04250\n");
	fprintf(fout,"CD     C      0.80540\n");
	fprintf(fout,"OE1    O2     -0.81880\n");
	fprintf(fout,"OE2    O2     -0.81880\n");
	fprintf(fout,"C      C      0.53660\n");
	fprintf(fout,"O      O      -0.58190\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASP Residue\n");
	fprintf(fout,"N      N      -0.51630\n");
	fprintf(fout,"H      H      0.29360\n");
	fprintf(fout,"CA     CT     0.03810\n");
	fprintf(fout,"HA     H1     0.08800\n");
	fprintf(fout,"CB     CT     -0.03030\n");
	fprintf(fout,"HB1    HC     -0.01220\n");
	fprintf(fout,"HB2    HC     -0.01220\n");
	fprintf(fout,"CG     C      0.79940\n");
	fprintf(fout,"OD1    O2     -0.80140\n");
	fprintf(fout,"OD2    O2     -0.80140\n");
	fprintf(fout,"C      C      0.53660\n");
	fprintf(fout,"O      O      -0.58190\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LYP Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     -0.00940\n");
	fprintf(fout,"HB1    HC     0.03620\n");
	fprintf(fout,"HB2    HC     0.03620\n");
	fprintf(fout,"CG     CT     0.01870\n");
	fprintf(fout,"HG1    HC     0.01030\n");
	fprintf(fout,"HG2    HC     0.01030\n");
	fprintf(fout,"CD     CT     -0.04790\n");
	fprintf(fout,"HD1    HC     0.06210\n");
	fprintf(fout,"HD2    HC     0.06210\n");
	fprintf(fout,"CE     CT     -0.01430\n");
	fprintf(fout,"HE1    HP     0.11350\n");
	fprintf(fout,"HE2    HP     0.11350\n");
	fprintf(fout,"NZ     N3     -0.38540\n");
	fprintf(fout,"HZ1    H      0.34000\n");
	fprintf(fout,"HZ2    H      0.34000\n");
	fprintf(fout,"HZ3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ORN Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.00990\n");
	fprintf(fout,"HB1    HC     0.03620\n");
	fprintf(fout,"HB2    HC     0.03620\n");
	fprintf(fout,"CG     CT     -0.02790\n");
	fprintf(fout,"HG1    HC     0.06210\n");
	fprintf(fout,"HG2    HC     0.06210\n");
	fprintf(fout,"CD     CT     -0.01430\n");
	fprintf(fout,"HD1    HP     0.11350\n");
	fprintf(fout,"HD2    HP     0.11350\n");
	fprintf(fout,"NE     N3     -0.38540\n");
	fprintf(fout,"HE1    H      0.34000\n");
	fprintf(fout,"HE2    H      0.34000\n");
	fprintf(fout,"HE3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DAB Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.02920\n");
	fprintf(fout,"HB1    HC     0.07470\n");
	fprintf(fout,"HB2    HC     0.07470\n");
	fprintf(fout,"CG     CT     -0.01430\n");
	fprintf(fout,"HG1    HP     0.11350\n");
	fprintf(fout,"HG2    HP     0.11350\n");
	fprintf(fout,"ND     N3     -0.38540\n");
	fprintf(fout,"HD1    H      0.34000\n");
	fprintf(fout,"HD2    H      0.34000\n");
	fprintf(fout,"HD3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LYN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.07206\n");
	fprintf(fout,"HA     H1     0.09940\n");
	fprintf(fout,"CB     CT     -0.04845\n");
	fprintf(fout,"HB1    HC     0.03400\n");
	fprintf(fout,"HB2    HC     0.03400\n");
	fprintf(fout,"CG     CT     0.06612\n");
	fprintf(fout,"HG1    HC     0.01041\n");
	fprintf(fout,"HG2    HC     0.01041\n");
	fprintf(fout,"CD     CT     -0.03768\n");
	fprintf(fout,"HD1    HC     0.01155\n");
	fprintf(fout,"HD2    HC     0.01155\n");
	fprintf(fout,"CE     CT     0.32604\n");
	fprintf(fout,"HE1    HP     -0.03358\n");
	fprintf(fout,"HE2    HP     -0.03358\n");
	fprintf(fout,"NZ     N3     -1.03581\n");
	fprintf(fout,"HZ1    H      0.38604\n");
	fprintf(fout,"HZ2    H      0.38604\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin PRO Residue\n");
	fprintf(fout,"N      N      -0.25480\n");
	fprintf(fout,"CD     CT     0.01920\n");
	fprintf(fout,"HD1    H1     0.03910\n");
	fprintf(fout,"HD2    H1     0.03910\n");
	fprintf(fout,"CG     CT     0.01890\n");
	fprintf(fout,"HG1    HC     0.02130\n");
	fprintf(fout,"HG2    HC     0.02130\n");
	fprintf(fout,"CB     CT     -0.00700\n");
	fprintf(fout,"HB1    HC     0.02530\n");
	fprintf(fout,"HB2    HC     0.02530\n");
	fprintf(fout,"CA     CT     -0.02660\n");
	fprintf(fout,"HA     H1     0.06410\n");
	fprintf(fout,"C      C      0.58960\n");
	fprintf(fout,"O      O      -0.57480\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HYP Residue\n");
	fprintf(fout,"N      N      -0.25480\n");
	fprintf(fout,"CD2    CT     0.05950\n");
	fprintf(fout,"HD21   H1     0.07000\n");
	fprintf(fout,"HD22   H1     0.07000\n");
	fprintf(fout,"CG     CT     0.04000\n");
	fprintf(fout,"HG     H1     0.04160\n");
	fprintf(fout,"OD1    OH     -0.61340\n");
	fprintf(fout,"HD1    HO     0.38510\n");
	fprintf(fout,"CB     CT     0.02030\n");
	fprintf(fout,"HB1    HC     0.04260\n");
	fprintf(fout,"HB2    HC     0.04260\n");
	fprintf(fout,"CA     CT     0.00470\n");
	fprintf(fout,"HA     H1     0.07700\n");
	fprintf(fout,"C      C      0.58960\n");
	fprintf(fout,"O      O      -0.57480\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.02130\n");
	fprintf(fout,"HA     H1     0.11240\n");
	fprintf(fout,"CB     CT     -0.12310\n");
	fprintf(fout,"HB1    H1     0.11120\n");
	fprintf(fout,"HB2    H1     0.11120\n");
	fprintf(fout,"SG     SH     -0.31190\n");
	fprintf(fout,"HG     HS     0.19330\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYM Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.03510\n");
	fprintf(fout,"HA     H1     0.05080\n");
	fprintf(fout,"CB     CT     -0.24130\n");
	fprintf(fout,"HB1    H1     0.11220\n");
	fprintf(fout,"HB2    H1     0.11220\n");
	fprintf(fout,"SG     SH     -0.88440\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYX Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.04290\n");
	fprintf(fout,"HA     H1     0.07660\n");
	fprintf(fout,"CB     CT     -0.07900\n");
	fprintf(fout,"HB1    H1     0.09100\n");
	fprintf(fout,"HB2    H1     0.09100\n");
	fprintf(fout,"SG     S      -0.10810\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYS2 Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.04290\n");
	fprintf(fout,"HA     H1     0.07660\n");
	fprintf(fout,"CB     CT     -0.07900\n");
	fprintf(fout,"HB1    H1     0.09100\n");
	fprintf(fout,"HB2    H1     0.09100\n");
	fprintf(fout,"SG     S      -0.10810\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin MET Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02370\n");
	fprintf(fout,"HA     H1     0.08800\n");
	fprintf(fout,"CB     CT     0.03420\n");
	fprintf(fout,"HB1    HC     0.02410\n");
	fprintf(fout,"HB2    HC     0.02410\n");
	fprintf(fout,"CG     CT     0.00180\n");
	fprintf(fout,"HG1    H1     0.04400\n");
	fprintf(fout,"HG2    H1     0.04400\n");
	fprintf(fout,"SD     S      -0.27370\n");
	fprintf(fout,"CE     CT     -0.05360\n");
	fprintf(fout,"HE1    H1     0.06840\n");
	fprintf(fout,"HE2    H1     0.06840\n");
	fprintf(fout,"HE3    H1     0.06840\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.03410\n");
	fprintf(fout,"HA     H1     0.08640\n");
	fprintf(fout,"CB     CT     -0.03160\n");
	fprintf(fout,"HB1    HC     0.04880\n");
	fprintf(fout,"HB2    HC     0.04880\n");
	fprintf(fout,"CG     C      0.64620\n");
	fprintf(fout,"OD1    O      -0.55540\n");
	fprintf(fout,"OD2    OH     -0.63760\n");
	fprintf(fout,"HD2    HO     0.47470\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01450\n");
	fprintf(fout,"HA     H1     0.07790\n");
	fprintf(fout,"CB     CT     -0.00710\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     -0.01740\n");
	fprintf(fout,"HG1    HC     0.04300\n");
	fprintf(fout,"HG2    HC     0.04300\n");
	fprintf(fout,"CD     C      0.68010\n");
	fprintf(fout,"OE1    O      -0.58380\n");
	fprintf(fout,"OE2    OH     -0.65110\n");
	fprintf(fout,"HE2    HO     0.46410\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CALA Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.17470\n");
	fprintf(fout,"HA     H1     0.10670\n");
	fprintf(fout,"CB     CT     -0.20930\n");
	fprintf(fout,"HB1    HC     0.07640\n");
	fprintf(fout,"HB2    HC     0.07640\n");
	fprintf(fout,"HB3    HC     0.07640\n");
	fprintf(fout,"C      C      0.77310\n");
	fprintf(fout,"OC1    O2     -0.80550\n");
	fprintf(fout,"OC2    O2     -0.80550\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLY Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.24930\n");
	fprintf(fout,"HA1    H1     0.10560\n");
	fprintf(fout,"HA2    H1     0.10560\n");
	fprintf(fout,"C      C      0.72310\n");
	fprintf(fout,"OC1    O2     -0.78550\n");
	fprintf(fout,"OC2    O2     -0.78550\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CSER Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.27220\n");
	fprintf(fout,"HA     H1     0.13040\n");
	fprintf(fout,"CB     CT     0.11230\n");
	fprintf(fout,"HB1    H1     0.08130\n");
	fprintf(fout,"HB2    H1     0.08130\n");
	fprintf(fout,"OG     OH     -0.65140\n");
	fprintf(fout,"HG     HO     0.44740\n");
	fprintf(fout,"C      C      0.81130\n");
	fprintf(fout,"OC1    O2     -0.81320\n");
	fprintf(fout,"OC2    O2     -0.81320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTHR Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.24200\n");
	fprintf(fout,"HA     H1     0.12070\n");
	fprintf(fout,"CB     CT     0.30250\n");
	fprintf(fout,"HB     H1     0.00780\n");
	fprintf(fout,"CG2    CT     -0.18530\n");
	fprintf(fout,"HG21   HC     0.05860\n");
	fprintf(fout,"HG22   HC     0.05860\n");
	fprintf(fout,"HG23   HC     0.05860\n");
	fprintf(fout,"OG1    OH     -0.64960\n");
	fprintf(fout,"HG1    HO     0.41190\n");
	fprintf(fout,"C      C      0.78100\n");
	fprintf(fout,"OC1    O2     -0.80440\n");
	fprintf(fout,"OC2    O2     -0.80440\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLEU Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.28470\n");
	fprintf(fout,"HA     H1     0.13460\n");
	fprintf(fout,"CB     CT     -0.24690\n");
	fprintf(fout,"HB1    HC     0.09740\n");
	fprintf(fout,"HB2    HC     0.09740\n");
	fprintf(fout,"CG     CT     0.37060\n");
	fprintf(fout,"HG     HC     -0.03740\n");
	fprintf(fout,"CD1    CT     -0.41630\n");
	fprintf(fout,"HD11   HC     0.10380\n");
	fprintf(fout,"HD12   HC     0.10380\n");
	fprintf(fout,"HD13   HC     0.10380\n");
	fprintf(fout,"CD2    CT     -0.41630\n");
	fprintf(fout,"HD21   HC     0.10380\n");
	fprintf(fout,"HD22   HC     0.10380\n");
	fprintf(fout,"HD23   HC     0.10380\n");
	fprintf(fout,"C      C      0.83260\n");
	fprintf(fout,"OC1    O2     -0.81990\n");
	fprintf(fout,"OC2    O2     -0.81990\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CILE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.31000\n");
	fprintf(fout,"HA     H1     0.13750\n");
	fprintf(fout,"CB     CT     0.03630\n");
	fprintf(fout,"HB     HC     0.07660\n");
	fprintf(fout,"CG2    CT     -0.34980\n");
	fprintf(fout,"HG21   HC     0.10210\n");
	fprintf(fout,"HG22   HC     0.10210\n");
	fprintf(fout,"HG23   HC     0.10210\n");
	fprintf(fout,"CG1    CT     -0.03230\n");
	fprintf(fout,"HG11   HC     0.03210\n");
	fprintf(fout,"HG12   HC     0.03210\n");
	fprintf(fout,"CD     CT     -0.06990\n");
	fprintf(fout,"HD1    HC     0.01960\n");
	fprintf(fout,"HD2    HC     0.01960\n");
	fprintf(fout,"HD3    HC     0.01960\n");
	fprintf(fout,"C      C      0.83430\n");
	fprintf(fout,"OC1    O2     -0.81900\n");
	fprintf(fout,"OC2    O2     -0.81900\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CVAL Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.34380\n");
	fprintf(fout,"HA     H1     0.14380\n");
	fprintf(fout,"CB     CT     0.19400\n");
	fprintf(fout,"HB     HC     0.03080\n");
	fprintf(fout,"CG1    CT     -0.30640\n");
	fprintf(fout,"HG11   HC     0.08360\n");
	fprintf(fout,"HG12   HC     0.08360\n");
	fprintf(fout,"HG13   HC     0.08360\n");
	fprintf(fout,"CG2    CT     -0.30640\n");
	fprintf(fout,"HG21   HC     0.08360\n");
	fprintf(fout,"HG22   HC     0.08360\n");
	fprintf(fout,"HG23   HC     0.08360\n");
	fprintf(fout,"C      C      0.83500\n");
	fprintf(fout,"OC1    O2     -0.81730\n");
	fprintf(fout,"OC2    O2     -0.81730\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CASN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20800\n");
	fprintf(fout,"HA     H1     0.13580\n");
	fprintf(fout,"CB     CT     -0.22990\n");
	fprintf(fout,"HB1    HC     0.10230\n");
	fprintf(fout,"HB2    HC     0.10230\n");
	fprintf(fout,"CG     C      0.71530\n");
	fprintf(fout,"OD1    O      -0.60100\n");
	fprintf(fout,"ND2    N      -0.90840\n");
	fprintf(fout,"HD21   H      0.41500\n");
	fprintf(fout,"HD22   H      0.41500\n");
	fprintf(fout,"C      C      0.80500\n");
	fprintf(fout,"OC1    O2     -0.81470\n");
	fprintf(fout,"OC2    O2     -0.81470\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.22480\n");
	fprintf(fout,"HA     H1     0.12320\n");
	fprintf(fout,"CB     CT     -0.06640\n");
	fprintf(fout,"HB1    HC     0.04520\n");
	fprintf(fout,"HB2    HC     0.04520\n");
	fprintf(fout,"CG     CT     -0.02100\n");
	fprintf(fout,"HG1    HC     0.02030\n");
	fprintf(fout,"HG2    HC     0.02030\n");
	fprintf(fout,"CD     C      0.70930\n");
	fprintf(fout,"OE1    O      -0.60980\n");
	fprintf(fout,"NE2    N      -0.95740\n");
	fprintf(fout,"HE21   H      0.43040\n");
	fprintf(fout,"HE22   H      0.43040\n");
	fprintf(fout,"C      C      0.77750\n");
	fprintf(fout,"OC1    O2     -0.80420\n");
	fprintf(fout,"OC2    O2     -0.80420\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CARG Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.30680\n");
	fprintf(fout,"HA     H1     0.14470\n");
	fprintf(fout,"CB     CT     -0.03740\n");
	fprintf(fout,"HB1    HC     0.03710\n");
	fprintf(fout,"HB2    HC     0.03710\n");
	fprintf(fout,"CG     CT     0.07440\n");
	fprintf(fout,"HG1    HC     0.01850\n");
	fprintf(fout,"HG2    HC     0.01850\n");
	fprintf(fout,"CD     CT     0.11140\n");
	fprintf(fout,"HD1    H1     0.04680\n");
	fprintf(fout,"HD2    H1     0.04680\n");
	fprintf(fout,"NE     N2     -0.55640\n");
	fprintf(fout,"HE     H      0.34790\n");
	fprintf(fout,"CZ     CA     0.83680\n");
	fprintf(fout,"NH1    N2     -0.87370\n");
	fprintf(fout,"HH11   H      0.44930\n");
	fprintf(fout,"HH12   H      0.44930\n");
	fprintf(fout,"NH2    N2     -0.87370\n");
	fprintf(fout,"HH21   H      0.44930\n");
	fprintf(fout,"HH22   H      0.44930\n");
	fprintf(fout,"C      C      0.85570\n");
	fprintf(fout,"OC1    O2     -0.82660\n");
	fprintf(fout,"OC2    O2     -0.82660\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHID Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.17390\n");
	fprintf(fout,"HA     H1     0.11000\n");
	fprintf(fout,"CB     CT     -0.10460\n");
	fprintf(fout,"HB1    HC     0.05650\n");
	fprintf(fout,"HB2    HC     0.05650\n");
	fprintf(fout,"CG     CC     0.02930\n");
	fprintf(fout,"ND1    NA     -0.38920\n");
	fprintf(fout,"HD1    H      0.37550\n");
	fprintf(fout,"CE1    CR     0.19250\n");
	fprintf(fout,"HE1    H5     0.14180\n");
	fprintf(fout,"NE2    NB     -0.56290\n");
	fprintf(fout,"CD2    CV     0.10010\n");
	fprintf(fout,"HD2    H4     0.12410\n");
	fprintf(fout,"C      C      0.76150\n");
	fprintf(fout,"OC1    O2     -0.80160\n");
	fprintf(fout,"OC2    O2     -0.80160\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHIE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.26990\n");
	fprintf(fout,"HA     H1     0.16500\n");
	fprintf(fout,"CB     CT     -0.10680\n");
	fprintf(fout,"HB1    HC     0.06200\n");
	fprintf(fout,"HB2    HC     0.06200\n");
	fprintf(fout,"CG     CC     0.27240\n");
	fprintf(fout,"ND1    NB     -0.55170\n");
	fprintf(fout,"CE1    CR     0.15580\n");
	fprintf(fout,"HE1    H5     0.14480\n");
	fprintf(fout,"NE2    NA     -0.26700\n");
	fprintf(fout,"HE2    H      0.33190\n");
	fprintf(fout,"CD2    CW     -0.25880\n");
	fprintf(fout,"HD2    H4     0.19570\n");
	fprintf(fout,"C      C      0.79160\n");
	fprintf(fout,"OC1    O2     -0.80650\n");
	fprintf(fout,"OC2    O2     -0.80650\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHIP Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.14450\n");
	fprintf(fout,"HA     H1     0.11150\n");
	fprintf(fout,"CB     CT     -0.08000\n");
	fprintf(fout,"HB1    HC     0.08680\n");
	fprintf(fout,"HB2    HC     0.08680\n");
	fprintf(fout,"CG     CC     0.02980\n");
	fprintf(fout,"ND1    NA     -0.15010\n");
	fprintf(fout,"HD1    H      0.38830\n");
	fprintf(fout,"CE1    CR     -0.02510\n");
	fprintf(fout,"HE1    H5     0.26940\n");
	fprintf(fout,"NE2    NA     -0.16830\n");
	fprintf(fout,"HE2    H      0.39130\n");
	fprintf(fout,"CD2    CW     -0.12560\n");
	fprintf(fout,"HD2    H4     0.23360\n");
	fprintf(fout,"C      C      0.80320\n");
	fprintf(fout,"OC1    O2     -0.81770\n");
	fprintf(fout,"OC2    O2     -0.81770\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTRP Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20840\n");
	fprintf(fout,"HA     H1     0.12720\n");
	fprintf(fout,"CB     CT     -0.07420\n");
	fprintf(fout,"HB1    HC     0.04970\n");
	fprintf(fout,"HB2    HC     0.04970\n");
	fprintf(fout,"CG     C*     -0.07960\n");
	fprintf(fout,"CD1    CW     -0.18080\n");
	fprintf(fout,"HD1    H4     0.20430\n");
	fprintf(fout,"NE1    NA     -0.33160\n");
	fprintf(fout,"HE1    H      0.34130\n");
	fprintf(fout,"CE2    CN     0.12220\n");
	fprintf(fout,"CZ2    CA     -0.25940\n");
	fprintf(fout,"HZ2    HA     0.15670\n");
	fprintf(fout,"CH2    CA     -0.10200\n");
	fprintf(fout,"HH2    HA     0.14010\n");
	fprintf(fout,"CZ3    CA     -0.22870\n");
	fprintf(fout,"HZ3    HA     0.15070\n");
	fprintf(fout,"CE3    CA     -0.18370\n");
	fprintf(fout,"HE3    HA     0.14910\n");
	fprintf(fout,"CD2    CB     0.10780\n");
	fprintf(fout,"C      C      0.76580\n");
	fprintf(fout,"OC1    O2     -0.80110\n");
	fprintf(fout,"OC2    O2     -0.80110\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CPHE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.18250\n");
	fprintf(fout,"HA     H1     0.10980\n");
	fprintf(fout,"CB     CT     -0.09590\n");
	fprintf(fout,"HB1    HC     0.04430\n");
	fprintf(fout,"HB2    HC     0.04430\n");
	fprintf(fout,"CG     CA     0.05520\n");
	fprintf(fout,"CD1    CA     -0.13000\n");
	fprintf(fout,"HD1    HA     0.14080\n");
	fprintf(fout,"CE1    CA     -0.18470\n");
	fprintf(fout,"HE1    HA     0.14610\n");
	fprintf(fout,"CZ     CA     -0.09440\n");
	fprintf(fout,"HZ     HA     0.12800\n");
	fprintf(fout,"CE2    CA     -0.18470\n");
	fprintf(fout,"HE2    HA     0.14610\n");
	fprintf(fout,"CD2    CA     -0.13000\n");
	fprintf(fout,"HD2    HA     0.14080\n");
	fprintf(fout,"C      C      0.76600\n");
	fprintf(fout,"OC1    O2     -0.80260\n");
	fprintf(fout,"OC2    O2     -0.80260\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTYR Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20150\n");
	fprintf(fout,"HA     H1     0.10920\n");
	fprintf(fout,"CB     CT     -0.07520\n");
	fprintf(fout,"HB1    HC     0.04900\n");
	fprintf(fout,"HB2    HC     0.04900\n");
	fprintf(fout,"CG     CA     0.02430\n");
	fprintf(fout,"CD1    CA     -0.19220\n");
	fprintf(fout,"HD1    HA     0.17800\n");
	fprintf(fout,"CE1    CA     -0.24580\n");
	fprintf(fout,"HE1    HA     0.16730\n");
	fprintf(fout,"CZ     C      0.33950\n");
	fprintf(fout,"OH     OH     -0.56430\n");
	fprintf(fout,"HH     HO     0.40170\n");
	fprintf(fout,"CE2    CA     -0.24580\n");
	fprintf(fout,"HE2    HA     0.16730\n");
	fprintf(fout,"CD2    CA     -0.19220\n");
	fprintf(fout,"HD2    HA     0.17800\n");
	fprintf(fout,"C      C      0.78170\n");
	fprintf(fout,"OC1    O2     -0.80700\n");
	fprintf(fout,"OC2    O2     -0.80700\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLU Residue\n");
	fprintf(fout,"N      N      -0.51920\n");
	fprintf(fout,"H      H      0.30550\n");
	fprintf(fout,"CA     CT     -0.20590\n");
	fprintf(fout,"HA     H1     0.13990\n");
	fprintf(fout,"CB     CT     0.00710\n");
	fprintf(fout,"HB1    HC     -0.00780\n");
	fprintf(fout,"HB2    HC     -0.00780\n");
	fprintf(fout,"CG     CT     0.06750\n");
	fprintf(fout,"HG1    HC     -0.05480\n");
	fprintf(fout,"HG2    HC     -0.05480\n");
	fprintf(fout,"CD     C      0.81830\n");
	fprintf(fout,"OE1    O2     -0.82200\n");
	fprintf(fout,"OE2    O2     -0.82200\n");
	fprintf(fout,"C      C      0.74200\n");
	fprintf(fout,"OC1    O2     -0.79300\n");
	fprintf(fout,"OC2    O2     -0.79300\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CASP Residue\n");
	fprintf(fout,"N      N      -0.51920\n");
	fprintf(fout,"H      H      0.30550\n");
	fprintf(fout,"CA     CT     -0.18170\n");
	fprintf(fout,"HA     H1     0.10460\n");
	fprintf(fout,"CB     CT     -0.06770\n");
	fprintf(fout,"HB1    HC     -0.02120\n");
	fprintf(fout,"HB2    HC     -0.02120\n");
	fprintf(fout,"CG     C      0.88510\n");
	fprintf(fout,"OD1    O2     -0.81620\n");
	fprintf(fout,"OD2    O2     -0.81620\n");
	fprintf(fout,"C      C      0.72560\n");
	fprintf(fout,"OC1    O2     -0.78870\n");
	fprintf(fout,"OC2    O2     -0.78870\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLYP Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.29030\n");
	fprintf(fout,"HA     H1     0.14380\n");
	fprintf(fout,"CB     CT     -0.05380\n");
	fprintf(fout,"HB1    HC     0.04820\n");
	fprintf(fout,"HB2    HC     0.04820\n");
	fprintf(fout,"CG     CT     0.02270\n");
	fprintf(fout,"HG1    HC     0.01340\n");
	fprintf(fout,"HG2    HC     0.01340\n");
	fprintf(fout,"CD     CT     -0.03920\n");
	fprintf(fout,"HD1    HC     0.06110\n");
	fprintf(fout,"HD2    HC     0.06110\n");
	fprintf(fout,"CE     CT     -0.01760\n");
	fprintf(fout,"HE1    HP     0.11210\n");
	fprintf(fout,"HE2    HP     0.11210\n");
	fprintf(fout,"NZ     N3     -0.37410\n");
	fprintf(fout,"HZ1    H      0.33740\n");
	fprintf(fout,"HZ2    H      0.33740\n");
	fprintf(fout,"HZ3    H      0.33740\n");
	fprintf(fout,"C      C      0.84880\n");
	fprintf(fout,"OC1    O2     -0.82520\n");
	fprintf(fout,"OC2    O2     -0.82520\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CPRO Residue\n");
	fprintf(fout,"N      N      -0.28020\n");
	fprintf(fout,"CD     CT     0.04340\n");
	fprintf(fout,"HD1    H1     0.03310\n");
	fprintf(fout,"HD2    H1     0.03310\n");
	fprintf(fout,"CG     CT     0.04660\n");
	fprintf(fout,"HG1    HC     0.01720\n");
	fprintf(fout,"HG2    HC     0.01720\n");
	fprintf(fout,"CB     CT     -0.05430\n");
	fprintf(fout,"HB1    HC     0.03810\n");
	fprintf(fout,"HB2    HC     0.03810\n");
	fprintf(fout,"CA     CT     -0.13360\n");
	fprintf(fout,"HA     H1     0.07760\n");
	fprintf(fout,"C      C      0.66310\n");
	fprintf(fout,"OC1    O2     -0.76970\n");
	fprintf(fout,"OC2    O2     -0.76970\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.16350\n");
	fprintf(fout,"HA     H1     0.13960\n");
	fprintf(fout,"CB     CT     -0.19960\n");
	fprintf(fout,"HB1    H1     0.14370\n");
	fprintf(fout,"HB2    H1     0.14370\n");
	fprintf(fout,"SG     SH     -0.31020\n");
	fprintf(fout,"HG     HS     0.20680\n");
	fprintf(fout,"C      C      0.74970\n");
	fprintf(fout,"OC1    O2     -0.79810\n");
	fprintf(fout,"OC2    O2     -0.79810\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYX Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.13180\n");
	fprintf(fout,"HA     H1     0.09380\n");
	fprintf(fout,"CB     CT     -0.19430\n");
	fprintf(fout,"HB1    H1     0.12280\n");
	fprintf(fout,"HB2    H1     0.12280\n");
	fprintf(fout,"SG     S      -0.05290\n");
	fprintf(fout,"C      C      0.76180\n");
	fprintf(fout,"OC1    O2     -0.80410\n");
	fprintf(fout,"OC2    O2     -0.80410\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CMET Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.25970\n");
	fprintf(fout,"HA     H1     0.12770\n");
	fprintf(fout,"CB     CT     -0.02360\n");
	fprintf(fout,"HB1    HC     0.04800\n");
	fprintf(fout,"HB2    HC     0.04800\n");
	fprintf(fout,"CG     CT     0.04920\n");
	fprintf(fout,"HG1    H1     0.03170\n");
	fprintf(fout,"HG2    H1     0.03170\n");
	fprintf(fout,"SD     S      -0.26920\n");
	fprintf(fout,"CE     CT     -0.03760\n");
	fprintf(fout,"HE1    H1     0.06250\n");
	fprintf(fout,"HE2    H1     0.06250\n");
	fprintf(fout,"HE3    H1     0.06250\n");
	fprintf(fout,"C      C      0.80130\n");
	fprintf(fout,"OC1    O2     -0.81050\n");
	fprintf(fout,"OC2    O2     -0.81050\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NALA Residue\n");
	fprintf(fout,"N      N3     0.14140\n");
	fprintf(fout,"H1     H      0.19970\n");
	fprintf(fout,"H2     H      0.19970\n");
	fprintf(fout,"H3     H      0.19970\n");
	fprintf(fout,"CA     CT     0.09620\n");
	fprintf(fout,"HA     HP     0.08890\n");
	fprintf(fout,"CB     CT     -0.05970\n");
	fprintf(fout,"HB1    HC     0.03000\n");
	fprintf(fout,"HB2    HC     0.03000\n");
	fprintf(fout,"HB3    HC     0.03000\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLY Residue\n");
	fprintf(fout,"N      N3     0.29430\n");
	fprintf(fout,"H1     H      0.16420\n");
	fprintf(fout,"H2     H      0.16420\n");
	fprintf(fout,"H3     H      0.16420\n");
	fprintf(fout,"CA     CT     -0.01000\n");
	fprintf(fout,"HA1    HP     0.08950\n");
	fprintf(fout,"HA2    HP     0.08950\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NSER Residue\n");
	fprintf(fout,"N      N3     0.18490\n");
	fprintf(fout,"H1     H      0.18980\n");
	fprintf(fout,"H2     H      0.18980\n");
	fprintf(fout,"H3     H      0.18980\n");
	fprintf(fout,"CA     CT     0.05670\n");
	fprintf(fout,"HA     HP     0.07820\n");
	fprintf(fout,"CB     CT     0.25960\n");
	fprintf(fout,"HB1    H1     0.02730\n");
	fprintf(fout,"HB2    H1     0.02730\n");
	fprintf(fout,"OG     OH     -0.67140\n");
	fprintf(fout,"HG     HO     0.42390\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTHR Residue\n");
	fprintf(fout,"N      N3     0.18120\n");
	fprintf(fout,"H1     H      0.19340\n");
	fprintf(fout,"H2     H      0.19340\n");
	fprintf(fout,"H3     H      0.19340\n");
	fprintf(fout,"CA     CT     0.00340\n");
	fprintf(fout,"HA     HP     0.10870\n");
	fprintf(fout,"CB     CT     0.45140\n");
	fprintf(fout,"HB     H1     -0.03230\n");
	fprintf(fout,"CG2    CT     -0.25540\n");
	fprintf(fout,"HG21   HC     0.06270\n");
	fprintf(fout,"HG22   HC     0.06270\n");
	fprintf(fout,"HG23   HC     0.06270\n");
	fprintf(fout,"OG1    OH     -0.67640\n");
	fprintf(fout,"HG1    HO     0.40700\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLEU Residue\n");
	fprintf(fout,"N      N3     0.10100\n");
	fprintf(fout,"H1     H      0.21480\n");
	fprintf(fout,"H2     H      0.21480\n");
	fprintf(fout,"H3     H      0.21480\n");
	fprintf(fout,"CA     CT     0.01040\n");
	fprintf(fout,"HA     HP     0.10530\n");
	fprintf(fout,"CB     CT     -0.02440\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     0.34210\n");
	fprintf(fout,"HG     HC     -0.03800\n");
	fprintf(fout,"CD1    CT     -0.41060\n");
	fprintf(fout,"HD11   HC     0.09800\n");
	fprintf(fout,"HD12   HC     0.09800\n");
	fprintf(fout,"HD13   HC     0.09800\n");
	fprintf(fout,"CD2    CT     -0.41040\n");
	fprintf(fout,"HD21   HC     0.09800\n");
	fprintf(fout,"HD22   HC     0.09800\n");
	fprintf(fout,"HD23   HC     0.09800\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NILE Residue\n");
	fprintf(fout,"N      N3     0.03110\n");
	fprintf(fout,"H1     H      0.23290\n");
	fprintf(fout,"H2     H      0.23290\n");
	fprintf(fout,"H3     H      0.23290\n");
	fprintf(fout,"CA     CT     0.02570\n");
	fprintf(fout,"HA     HP     0.10310\n");
	fprintf(fout,"CB     CT     0.18850\n");
	fprintf(fout,"HB     HC     0.02130\n");
	fprintf(fout,"CG2    CT     -0.37200\n");
	fprintf(fout,"HG21   HC     0.09470\n");
	fprintf(fout,"HG22   HC     0.09470\n");
	fprintf(fout,"HG23   HC     0.09470\n");
	fprintf(fout,"CG1    CT     -0.03870\n");
	fprintf(fout,"HG11   HC     0.02010\n");
	fprintf(fout,"HG12   HC     0.02010\n");
	fprintf(fout,"CD     CT     -0.09080\n");
	fprintf(fout,"HD1    HC     0.02260\n");
	fprintf(fout,"HD2    HC     0.02260\n");
	fprintf(fout,"HD3    HC     0.02260\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NVAL Residue\n");
	fprintf(fout,"N      N3     0.05770\n");
	fprintf(fout,"H1     H      0.22720\n");
	fprintf(fout,"H2     H      0.22720\n");
	fprintf(fout,"H3     H      0.22720\n");
	fprintf(fout,"CA     CT     -0.00540\n");
	fprintf(fout,"HA     HP     0.10930\n");
	fprintf(fout,"CB     CT     0.31960\n");
	fprintf(fout,"HB     HC     -0.02210\n");
	fprintf(fout,"CG1    CT     -0.31290\n");
	fprintf(fout,"HG11   HC     0.07350\n");
	fprintf(fout,"HG12   HC     0.07350\n");
	fprintf(fout,"HG13   HC     0.07350\n");
	fprintf(fout,"CG2    CT     -0.31290\n");
	fprintf(fout,"HG21   HC     0.07350\n");
	fprintf(fout,"HG22   HC     0.07350\n");
	fprintf(fout,"HG23   HC     0.07350\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NASN Residue\n");
	fprintf(fout,"N      N3     0.18010\n");
	fprintf(fout,"H1     H      0.19210\n");
	fprintf(fout,"H2     H      0.19210\n");
	fprintf(fout,"H3     H      0.19210\n");
	fprintf(fout,"CA     CT     0.03680\n");
	fprintf(fout,"HA     HP     0.12310\n");
	fprintf(fout,"CB     CT     -0.02830\n");
	fprintf(fout,"HB1    HC     0.05150\n");
	fprintf(fout,"HB2    HC     0.05150\n");
	fprintf(fout,"CG     C      0.58330\n");
	fprintf(fout,"OD1    O      -0.57440\n");
	fprintf(fout,"ND2    N      -0.86340\n");
	fprintf(fout,"HD21   H      0.40970\n");
	fprintf(fout,"HD22   H      0.40970\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLN Residue\n");
	fprintf(fout,"N      N3     0.14930\n");
	fprintf(fout,"H1     H      0.19960\n");
	fprintf(fout,"H2     H      0.19960\n");
	fprintf(fout,"H3     H      0.19960\n");
	fprintf(fout,"CA     CT     0.05360\n");
	fprintf(fout,"HA     HP     0.10150\n");
	fprintf(fout,"CB     CT     0.06510\n");
	fprintf(fout,"HB1    HC     0.00500\n");
	fprintf(fout,"HB2    HC     0.00500\n");
	fprintf(fout,"CG     CT     -0.09030\n");
	fprintf(fout,"HG1    HC     0.03310\n");
	fprintf(fout,"HG2    HC     0.03310\n");
	fprintf(fout,"CD     C      0.73540\n");
	fprintf(fout,"OE1    O      -0.61330\n");
	fprintf(fout,"NE2    N      -1.00310\n");
	fprintf(fout,"HE21   H      0.44290\n");
	fprintf(fout,"HE22   H      0.44290\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NARG Residue\n");
	fprintf(fout,"N      N3     0.13050\n");
	fprintf(fout,"H1     H      0.20830\n");
	fprintf(fout,"H2     H      0.20830\n");
	fprintf(fout,"H3     H      0.20830\n");
	fprintf(fout,"CA     CT     -0.02230\n");
	fprintf(fout,"HA     HP     0.12420\n");
	fprintf(fout,"CB     CT     0.01180\n");
	fprintf(fout,"HB1    HC     0.02260\n");
	fprintf(fout,"HB2    HC     0.02260\n");
	fprintf(fout,"CG     CT     0.02360\n");
	fprintf(fout,"HG1    HC     0.03090\n");
	fprintf(fout,"HG2    HC     0.03090\n");
	fprintf(fout,"CD     CT     0.09350\n");
	fprintf(fout,"HD1    H1     0.05270\n");
	fprintf(fout,"HD2    H1     0.05270\n");
	fprintf(fout,"NE     N2     -0.56500\n");
	fprintf(fout,"HE     H      0.35920\n");
	fprintf(fout,"CZ     CA     0.82810\n");
	fprintf(fout,"NH1    N2     -0.86930\n");
	fprintf(fout,"HH11   H      0.44940\n");
	fprintf(fout,"HH12   H      0.44940\n");
	fprintf(fout,"NH2    N2     -0.86930\n");
	fprintf(fout,"HH21   H      0.44940\n");
	fprintf(fout,"HH22   H      0.44940\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHID Residue\n");
	fprintf(fout,"N      N3     0.15420\n");
	fprintf(fout,"H1     H      0.19630\n");
	fprintf(fout,"H2     H      0.19630\n");
	fprintf(fout,"H3     H      0.19630\n");
	fprintf(fout,"CA     CT     0.09640\n");
	fprintf(fout,"HA     HP     0.09580\n");
	fprintf(fout,"CB     CT     0.02590\n");
	fprintf(fout,"HB1    HC     0.02090\n");
	fprintf(fout,"HB2    HC     0.02090\n");
	fprintf(fout,"CG     CC     -0.03990\n");
	fprintf(fout,"ND1    NA     -0.38190\n");
	fprintf(fout,"HD1    H      0.36320\n");
	fprintf(fout,"CE1    CR     0.21270\n");
	fprintf(fout,"HE1    H5     0.13850\n");
	fprintf(fout,"NE2    NB     -0.57110\n");
	fprintf(fout,"CD2    CV     0.10460\n");
	fprintf(fout,"HD2    H4     0.12990\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHIE Residue\n");
	fprintf(fout,"N      N3     0.14720\n");
	fprintf(fout,"H1     H      0.20160\n");
	fprintf(fout,"H2     H      0.20160\n");
	fprintf(fout,"H3     H      0.20160\n");
	fprintf(fout,"CA     CT     0.02360\n");
	fprintf(fout,"HA     HP     0.13800\n");
	fprintf(fout,"CB     CT     0.04890\n");
	fprintf(fout,"HB1    HC     0.02230\n");
	fprintf(fout,"HB2    HC     0.02230\n");
	fprintf(fout,"CG     CC     0.17400\n");
	fprintf(fout,"ND1    NB     -0.55790\n");
	fprintf(fout,"CE1    CR     0.18040\n");
	fprintf(fout,"HE1    H5     0.13970\n");
	fprintf(fout,"NE2    NA     -0.27810\n");
	fprintf(fout,"HE2    H      0.33240\n");
	fprintf(fout,"CD2    CW     -0.23490\n");
	fprintf(fout,"HD2    H4     0.19630\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHIP Residue\n");
	fprintf(fout,"N      N3     0.25600\n");
	fprintf(fout,"H1     H      0.17040\n");
	fprintf(fout,"H2     H      0.17040\n");
	fprintf(fout,"H3     H      0.17040\n");
	fprintf(fout,"CA     CT     0.05810\n");
	fprintf(fout,"HA     HP     0.10470\n");
	fprintf(fout,"CB     CT     0.04840\n");
	fprintf(fout,"HB1    HC     0.05310\n");
	fprintf(fout,"HB2    HC     0.05310\n");
	fprintf(fout,"CG     CC     -0.02360\n");
	fprintf(fout,"ND1    NA     -0.15100\n");
	fprintf(fout,"HD1    H      0.38210\n");
	fprintf(fout,"CE1    CR     -0.00110\n");
	fprintf(fout,"HE1    H5     0.26450\n");
	fprintf(fout,"NE2    NA     -0.17390\n");
	fprintf(fout,"HE2    H      0.39210\n");
	fprintf(fout,"CD2    CW     -0.14330\n");
	fprintf(fout,"HD2    H4     0.24950\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTRP Residue\n");
	fprintf(fout,"N      N3     0.19130\n");
	fprintf(fout,"H1     H      0.18880\n");
	fprintf(fout,"H2     H      0.18880\n");
	fprintf(fout,"H3     H      0.18880\n");
	fprintf(fout,"CA     CT     0.04210\n");
	fprintf(fout,"HA     HP     0.11620\n");
	fprintf(fout,"CB     CT     0.05430\n");
	fprintf(fout,"HB1    HC     0.02220\n");
	fprintf(fout,"HB2    HC     0.02220\n");
	fprintf(fout,"CG     C*     -0.16540\n");
	fprintf(fout,"CD1    CW     -0.17880\n");
	fprintf(fout,"HD1    H4     0.21950\n");
	fprintf(fout,"NE1    NA     -0.34440\n");
	fprintf(fout,"HE1    H      0.34120\n");
	fprintf(fout,"CE2    CN     0.15750\n");
	fprintf(fout,"CZ2    CA     -0.27100\n");
	fprintf(fout,"HZ2    HA     0.15890\n");
	fprintf(fout,"CH2    CA     -0.10800\n");
	fprintf(fout,"HH2    HA     0.14110\n");
	fprintf(fout,"CZ3    CA     -0.20340\n");
	fprintf(fout,"HZ3    HA     0.14580\n");
	fprintf(fout,"CE3    CA     -0.22650\n");
	fprintf(fout,"HE3    HA     0.16460\n");
	fprintf(fout,"CD2    CB     0.11320\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NPHE Residue\n");
	fprintf(fout,"N      N3     0.17370\n");
	fprintf(fout,"H1     H      0.19210\n");
	fprintf(fout,"H2     H      0.19210\n");
	fprintf(fout,"H3     H      0.19210\n");
	fprintf(fout,"CA     CT     0.07330\n");
	fprintf(fout,"HA     HP     0.10410\n");
	fprintf(fout,"CB     CT     0.03300\n");
	fprintf(fout,"HB1    HC     0.01040\n");
	fprintf(fout,"HB2    HC     0.01040\n");
	fprintf(fout,"CG     CA     0.00310\n");
	fprintf(fout,"CD1    CA     -0.13920\n");
	fprintf(fout,"HD1    HA     0.13740\n");
	fprintf(fout,"CE1    CA     -0.16020\n");
	fprintf(fout,"HE1    HA     0.14330\n");
	fprintf(fout,"CZ     CA     -0.12080\n");
	fprintf(fout,"HZ     HA     0.13290\n");
	fprintf(fout,"CE2    CA     -0.16030\n");
	fprintf(fout,"HE2    HA     0.14330\n");
	fprintf(fout,"CD2    CA     -0.13910\n");
	fprintf(fout,"HD2    HA     0.13740\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTYR Residue\n");
	fprintf(fout,"N      N3     0.19400\n");
	fprintf(fout,"H1     H      0.18730\n");
	fprintf(fout,"H2     H      0.18730\n");
	fprintf(fout,"H3     H      0.18730\n");
	fprintf(fout,"CA     CT     0.05700\n");
	fprintf(fout,"HA     HP     0.09830\n");
	fprintf(fout,"CB     CT     0.06590\n");
	fprintf(fout,"HB1    HC     0.01020\n");
	fprintf(fout,"HB2    HC     0.01020\n");
	fprintf(fout,"CG     CA     -0.02050\n");
	fprintf(fout,"CD1    CA     -0.20020\n");
	fprintf(fout,"HD1    HA     0.17200\n");
	fprintf(fout,"CE1    CA     -0.22390\n");
	fprintf(fout,"HE1    HA     0.16500\n");
	fprintf(fout,"CZ     C      0.31390\n");
	fprintf(fout,"OH     OH     -0.55780\n");
	fprintf(fout,"HH     HO     0.40010\n");
	fprintf(fout,"CE2    CA     -0.22390\n");
	fprintf(fout,"HE2    HA     0.16500\n");
	fprintf(fout,"CD2    CA     -0.20020\n");
	fprintf(fout,"HD2    HA     0.17200\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLU Residue\n");
	fprintf(fout,"N      N3     0.00170\n");
	fprintf(fout,"H1     H      0.23910\n");
	fprintf(fout,"H2     H      0.23910\n");
	fprintf(fout,"H3     H      0.23910\n");
	fprintf(fout,"CA     CT     0.05880\n");
	fprintf(fout,"HA     HP     0.12020\n");
	fprintf(fout,"CB     CT     0.09090\n");
	fprintf(fout,"HB1    HC     -0.02320\n");
	fprintf(fout,"HB2    HC     -0.02320\n");
	fprintf(fout,"CG     CT     -0.02360\n");
	fprintf(fout,"HG1    HC     -0.03150\n");
	fprintf(fout,"HG2    HC     -0.03150\n");
	fprintf(fout,"CD     C      0.80870\n");
	fprintf(fout,"OE1    O2     -0.81890\n");
	fprintf(fout,"OE2    O2     -0.81890\n");
	fprintf(fout,"C      C      0.56210\n");
	fprintf(fout,"O      O      -0.58890\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NASP Residue\n");
	fprintf(fout,"N      N3     0.07820\n");
	fprintf(fout,"H1     H      0.22000\n");
	fprintf(fout,"H2     H      0.22000\n");
	fprintf(fout,"H3     H      0.22000\n");
	fprintf(fout,"CA     CT     0.02920\n");
	fprintf(fout,"HA     HP     0.11410\n");
	fprintf(fout,"CB     CT     -0.02350\n");
	fprintf(fout,"HB1    HC     -0.01690\n");
	fprintf(fout,"HB2    HC     -0.01690\n");
	fprintf(fout,"CG     C      0.81940\n");
	fprintf(fout,"OD1    O2     -0.80840\n");
	fprintf(fout,"OD2    O2     -0.80840\n");
	fprintf(fout,"C      C      0.56210\n");
	fprintf(fout,"O      O      -0.58890\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLYP Residue\n");
	fprintf(fout,"N      N3     0.09660\n");
	fprintf(fout,"H1     H      0.21650\n");
	fprintf(fout,"H2     H      0.21650\n");
	fprintf(fout,"H3     H      0.21650\n");
	fprintf(fout,"CA     CT     -0.00150\n");
	fprintf(fout,"HA     HP     0.11800\n");
	fprintf(fout,"CB     CT     0.02120\n");
	fprintf(fout,"HB1    HC     0.02830\n");
	fprintf(fout,"HB2    HC     0.02830\n");
	fprintf(fout,"CG     CT     -0.00480\n");
	fprintf(fout,"HG1    HC     0.01210\n");
	fprintf(fout,"HG2    HC     0.01210\n");
	fprintf(fout,"CD     CT     -0.06080\n");
	fprintf(fout,"HD1    HC     0.06330\n");
	fprintf(fout,"HD2    HC     0.06330\n");
	fprintf(fout,"CE     CT     -0.01810\n");
	fprintf(fout,"HE1    HP     0.11710\n");
	fprintf(fout,"HE2    HP     0.11710\n");
	fprintf(fout,"NZ     N3     -0.37640\n");
	fprintf(fout,"HZ1    H      0.33820\n");
	fprintf(fout,"HZ2    H      0.33820\n");
	fprintf(fout,"HZ3    H      0.33820\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NPRO Residue\n");
	fprintf(fout,"N      N3     -0.20200\n");
	fprintf(fout,"H1     H      0.31200\n");
	fprintf(fout,"H2     H      0.31200\n");
	fprintf(fout,"CD     CT     -0.01200\n");
	fprintf(fout,"HD1    HP     0.10000\n");
	fprintf(fout,"HD2    HP     0.10000\n");
	fprintf(fout,"CG     CT     -0.12100\n");
	fprintf(fout,"HG1    HC     0.10000\n");
	fprintf(fout,"HG2    HC     0.10000\n");
	fprintf(fout,"CB     CT     -0.11500\n");
	fprintf(fout,"HB1    HC     0.10000\n");
	fprintf(fout,"HB2    HC     0.10000\n");
	fprintf(fout,"CA     CT     0.10000\n");
	fprintf(fout,"HA     HP     0.10000\n");
	fprintf(fout,"C      C      0.52600\n");
	fprintf(fout,"O      O      -0.50000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NCYN Residue\n");
	fprintf(fout,"N      N3     0.13250\n");
	fprintf(fout,"H1     H      0.20230\n");
	fprintf(fout,"H2     H      0.20230\n");
	fprintf(fout,"H3     H      0.20230\n");
	fprintf(fout,"CA     CT     0.09270\n");
	fprintf(fout,"HA     HP     0.14110\n");
	fprintf(fout,"CB     CT     -0.11950\n");
	fprintf(fout,"HB1    H1     0.11880\n");
	fprintf(fout,"HB2    H1     0.11880\n");
	fprintf(fout,"SG     SH     -0.32980\n");
	fprintf(fout,"HG     HS     0.19750\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NCYX Residue\n");
	fprintf(fout,"N      N3     0.20690\n");
	fprintf(fout,"H1     H      0.18150\n");
	fprintf(fout,"H2     H      0.18150\n");
	fprintf(fout,"H3     H      0.18150\n");
	fprintf(fout,"CA     CT     0.10550\n");
	fprintf(fout,"HA     HP     0.09220\n");
	fprintf(fout,"CB     CT     -0.02770\n");
	fprintf(fout,"HB1    H1     0.06800\n");
	fprintf(fout,"HB2    H1     0.06800\n");
	fprintf(fout,"SG     S      -0.09840\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NMET Residue\n");
	fprintf(fout,"N      N3     0.15920\n");
	fprintf(fout,"H1     H      0.19840\n");
	fprintf(fout,"H2     H      0.19840\n");
	fprintf(fout,"H3     H      0.19840\n");
	fprintf(fout,"CA     CT     0.02210\n");
	fprintf(fout,"HA     HP     0.11160\n");
	fprintf(fout,"CB     CT     0.08650\n");
	fprintf(fout,"HB1    HC     0.01250\n");
	fprintf(fout,"HB2    HC     0.01250\n");
	fprintf(fout,"CG     CT     0.03340\n");
	fprintf(fout,"HG1    H1     0.02920\n");
	fprintf(fout,"HG2    H1     0.02920\n");
	fprintf(fout,"SD     S      -0.27740\n");
	fprintf(fout,"CE     CT     -0.03410\n");
	fprintf(fout,"HE1    H1     0.05970\n");
	fprintf(fout,"HE2    H1     0.05970\n");
	fprintf(fout,"HE3    H1     0.05970\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DA5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DA Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.02920\n");
	fprintf(fout,"HB1    HC     0.07470\n");
	fprintf(fout,"HB2    HC     0.07470\n");
	fprintf(fout,"CG     CT     -0.01430\n");
	fprintf(fout,"HG1    HP     0.11350\n");
	fprintf(fout,"HG2    HP     0.11350\n");
	fprintf(fout,"ND     N3     -0.38540\n");
	fprintf(fout,"HD1    H      0.34000\n");
	fprintf(fout,"HD2    H      0.34000\n");
	fprintf(fout,"HD3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DA3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DAN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RAN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DTN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RUN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DGN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.26370\n");
	fprintf(fout,"HA     H1     0.15600\n");
	fprintf(fout,"CB     CT     -0.00070\n");
	fprintf(fout,"HB1    HC     0.03270\n");
	fprintf(fout,"HB2    HC     0.03270\n");
	fprintf(fout,"CG     CT     0.03900\n");
	fprintf(fout,"HG1    HC     0.02850\n");
	fprintf(fout,"HG2    HC     0.02850\n");
	fprintf(fout,"CD     CT     0.04860\n");
	fprintf(fout,"HD1    H1     0.06870\n");
	fprintf(fout,"HD2    H1     0.06870\n");
	fprintf(fout,"NE     N2     -0.52950\n");
	fprintf(fout,"HE     H      0.34560\n");
	fprintf(fout,"CZ     CA     0.80760\n");
	fprintf(fout,"NH1    N2     -0.86270\n");
	fprintf(fout,"HH11   H      0.44780\n");
	fprintf(fout,"HH12   H      0.44780\n");
	fprintf(fout,"NH2    N2     -0.86270\n");
	fprintf(fout,"HH21   H      0.44780\n");
	fprintf(fout,"HH22   H      0.44780\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RGN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DCN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RCN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");
}
/************************************************************/
int main()
{
	FILE* fout = fopen("TEST.TPL","w");
	if(!fout)
		return 1;
	createTitleResidueTpl(fout);
	createListResidueTpl(fout);
	createResidueTpl(fout);
	return 0;
}
